bd1tobd5: Convert a format 1 binary dosage file to Format 5

View source: R/convert.R

bd1tobd5R Documentation

Convert a format 1 binary dosage file to Format 5

Description

Reads a format 1 binary dosage file (subformat 1 or 2) and converts it to a Format 5 file pair. If the source file does not contain genotype probabilities (subformat 1), those values are stored as missing in the output.

Usage

bd1tobd5(bdfiles, bdose_file)

Arguments

bdfiles

Vector of three file names for the format 1 binary dosage file: the binary dosage file, the family file, and the map file.

bdose_file

Path for the output .bdose file. The companion .bdi metadata file is written to paste0(bdose_file, ".bdi").

Value

NULL (invisibly)


BinaryDosage documentation built on April 30, 2026, 1:09 a.m.