bd4tobd5: Convert a format 4 binary dosage file to Format 5

View source: R/convert.R

bd4tobd5R Documentation

Convert a format 4 binary dosage file to Format 5

Description

Reads a format 4 binary dosage file (subformat 1, 2, 3, or 4) and converts it to a Format 5 file pair. If the source file does not contain genotype probabilities (subformats 1 and 3), those values are stored as missing in the output.

Usage

bd4tobd5(bdfile, bdose_file)

Arguments

bdfile

File name of the format 4 binary dosage file. Format 4 stores all data in a single file.

bdose_file

Path for the output .bdose file. The companion .bdi metadata file is written to paste0(bdose_file, ".bdi").

Value

NULL (invisibly)


BinaryDosage documentation built on April 30, 2026, 1:09 a.m.