getbdinfo: Get information about a binary dosage file

View source: R/getinfo.R

getbdinfoR Documentation

Get information about a binary dosage file

Description

Routine to return information about a binary dosage file. This information is used by other routines to allow for quicker extraction of values from the file.

Usage

getbdinfo(bdfiles)

Arguments

bdfiles

Vector of file names. For Format 5 files, a single .bdose file name; the companion .bdi metadata file is read automatically from paste0(bdfiles[1], ".bdi"). For format 4, a single file name. For formats 1, 2, and 3, a vector of three file names: the binary dosage file, the family information file, and the SNP information file.

Value

List with information about the binary dosage file. This includes family and subject IDs along with a list of the SNPs in the file. Other information needed to read the file is also included.

Examples

vcf1abdfile <- system.file("extdata", "vcf1a.bdose", package = "BinaryDosage")
bdinfo <- getbdinfo(bdfiles = vcf1abdfile)

BinaryDosage documentation built on April 30, 2026, 1:09 a.m.