| bd2tobd5 | R Documentation |
Reads a format 2 binary dosage file (subformat 1 or 2) and converts it to a Format 5 file pair. If the source file does not contain genotype probabilities (subformat 1), those values are stored as missing in the output.
bd2tobd5(bdfiles, bdose_file)
bdfiles |
Vector of three file names for the format 2 binary dosage file: the binary dosage file, the family file, and the map file. |
bdose_file |
Path for the output .bdose file. The companion .bdi
metadata file is written to |
NULL (invisibly)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.