| bd4tobd5 | R Documentation |
Reads a format 4 binary dosage file (subformat 1, 2, 3, or 4) and converts it to a Format 5 file pair. If the source file does not contain genotype probabilities (subformats 1 and 3), those values are stored as missing in the output.
bd4tobd5(bdfile, bdose_file)
bdfile |
File name of the format 4 binary dosage file. Format 4 stores all data in a single file. |
bdose_file |
Path for the output .bdose file. The companion .bdi
metadata file is written to |
NULL (invisibly)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.