| closebd5con | R Documentation |
Explicitly closes the connection opened by openbd5con. Calling
this is optional — the finalizer will close it on garbage collection or
R exit — but explicit close is preferred to release the file handle
promptly.
closebd5con(bd5con)
bd5con |
Object returned by |
NULL invisibly.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.