| getbdinfo | R Documentation |
Routine to return information about a binary dosage file. This information is used by other routines to allow for quicker extraction of values from the file.
getbdinfo(bdfiles)
bdfiles |
Vector of file names. For Format 5 files, a single .bdose
file name; the companion .bdi metadata file is read automatically from
|
List with information about the binary dosage file. This includes family and subject IDs along with a list of the SNPs in the file. Other information needed to read the file is also included.
vcf1abdfile <- system.file("extdata", "vcf1a.bdose", package = "BinaryDosage")
bdinfo <- getbdinfo(bdfiles = vcf1abdfile)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.